/*REPLICATES TABLES IN FIGURES IN APPENDIX*/

clear
set more off
set matsize 4000
set trace on
set tracedepth 2

****************
*DIRECTORY*
****************

    adopath + C:\Users\cecilia.machado\Dropbox\jmp_revision\jae_revision\replication
    global replication  C:\Users\cecilia.machado\Dropbox\jmp_revision\jae_revision\replication\  

	
*******************
/*TABLE A1*/
*******************

capture program drop tableA1
program define tableA1	
	
	
	clear
    insheet using ${replication}nlsy79.csv	

	// AVERAGE OUTCOMES: 
	
	local ae count ae0_ftfy ae0_ftfywc
	local vars iq_afqtrank iq_pca4rank iq_pca10rank managers hiprof cumul_numhours44 pct_ftfy 
	global x: word count `vars'
	matrix D=J(${x}+1,4,0)

	local j=0
	local weight weight_panel_2012
	
	foreach type in `ae' {
	
	if "`j'"=="0" local cond replace
	if "`j'"!="0" local cond append
	
	tabstat `vars' [aw=`weight'] if `type'==1 & year==1979, stats(mean) by(female) save
	matrix A`type'=r(Stat1)', r(Stat2)'
	tabstat count [aw=`weight'] if `type'==1 & year==1979, stats(count) by(female) save
	matrix C=r(Stat1)',r(Stat2)'
	matrix A`type'=A`type'\C
	
	local k=1
	foreach v in `vars' {
	regress `v' female [aw=`weight'] if `type'==1 & year==1979
	matrix D[`k',1]=_b[female]
	matrix D[`k',2]=_se[female]
	matrix D[`k',3]=_b[female]/_se[female]
	local t= _b[female]/_se[female]
	matrix D[`k',4]=2*ttail(e(df_r),abs(`t'))
	local k=`k'+1
	}
	
	matrix A`type'=A`type',D
	matrix colnames A`type' = "MALE" "FEMALE" "Diff" "SE" "t-stat" "p-value" 
    matrix B`type'=A`type''
	esttab matrix(B`type',fmt(3)) using ${replication}tableA1.tex, `cond' //.tex works as well

	local j=`j'+1
	}
end // program tableA1


*******************
/*TABLE A2*/
*******************

capture program drop tableA2
program define tableA2

	// COMBINE DATA
	
	clear
    insheet using ${replication}youngwomen.csv	
	g dataset = "youngwomen"
	tempfile yw
	save `yw', replace
	
	clear
    insheet using ${replication}nlsy79.csv	
	g dataset = "nlsy79"
	tempfile nlsy79
	save `nlsy79', replace
	
	use `yw', clear
	append using `nlsy79'
	drop if female==0
	gen firstyear=(dataset=="nlsy79"& year==1979)|(dataset=="youngwomen"& year==1968)
	
	drop count
	gen count=1

	// AVERAGE OUTCOMES: 
	
	drop e11v*
	replace c_childunder6=c_childunder6_v2 if dataset=="nlsy79"
	
	gen E11v1_ftfy=(pct_aecsa_ftfy==1) if c_childunder6>0 /* trabalhou todos os perídos com childunder6==1 */
	gen E11v2_ftfy=(pct_aecsa_ftfy>0.5) if c_childunder6>0 /* trabalhou pelo menos metade do perído com childunder6==1 */
	gen E11v3_ftfy=(pct_aecsa_ftfy>0) if c_childunder6>0 /* trabalhou pelo menos um perído com childunder6==1 */
	
	replace c_childunder6=(c_childunder6>0)
	
	local ae count c_childunder6 E11v3_ftfy E11v2_ftfy E11v1_ftfy
	local vars iqrank managers hiprof pct_ftfy 
	global x: word count `vars'
	matrix D=J(${x}+1,4,0)

	local j=0
	replace weight_panel=weight_panel_2012 if dataset=="nlsy79"
	local weight weight_panel
	replace iqrank=iq_afqtrank if dataset=="nlsy79"
	
	drop female
	gen female=(dataset=="youngwomen")
	
	foreach type in `ae' {
	
	gen type=`type'
	
	if "`j'"=="0" local cond replace
	if "`j'"!="0" local cond append
	
	tabstat `vars' [aw=`weight'] if type==1 & firstyear==1, stats(mean) by(female) save
	matrix A`type'=r(Stat1)', r(Stat2)'
	tabstat count [aw=`weight'] if type==1 & firstyear==1, stats(count) by(female) save
	matrix C=r(Stat1)',r(Stat2)'
	matrix A`type'=A`type'\C
	
	local k=1
	foreach v in `vars' {
	regress `v' female [aw=`weight'] if type==1 & firstyear==1
	matrix D[`k',1]=_b[female]
	matrix D[`k',2]=_se[female]
	matrix D[`k',3]=_b[female]/_se[female]
	local t= _b[female]/_se[female]
	matrix D[`k',4]=2*ttail(e(df_r),abs(`t'))
	local k=`k'+1
	}
	
	matrix A`type'=A`type',D
	matrix colnames A`type' = "MALE" "FEMALE" "Diff" "SE" "t-stat" "p-value" 
	matrix B`type'=A`type''
	esttab matrix(B`type',fmt(3)) using ${replication}tableA2.tex, `cond' //.tex works as well

	local j=`j'+1
	
	drop type
	
	}

end // program tableA2

*******************
/*TABLE A3*/
*******************

capture program drop tableA3
program define tableA3

clear
insheet using ${replication}mar_match.csv	

foreach participation in ft employed {
qui reg w_`participation' eduhslesst* edu12t* edu1315t* educollegeplust* femalet* aftert* fat* [pw=wgt] if e1e1_`participation'==1, noc
estimates store `participation'

lincom femalet2004+fat2004
scalar sum_a=r(estimate)
scalar se_a=r(se)

lincom femalet2004+fat2004-femalet1979
scalar sum_b=r(estimate)
scalar se_b=r(se)
lincom fat1979+fat1980+fat1981+fat1982+fat1983+fat1984+fat1986+fat1987+fat1988+fat1989+fat1990+fat1991+fat1992+fat1993+fat1994+fat1996+fat1997+fat1998+fat1999+fat2000+fat2001+fat2002+fat2003+fat2004
scalar sum_c=r(estimate)
scalar se_c=r(se)
lincom fat1979+fat1980+fat1981+fat1982+fat1983+2*fat1984+fat1986+fat1987+fat1988+fat1989+fat1990+fat1991+fat1992+fat1993+2*fat1994+fat1996+fat1997+fat1998+fat1999+fat2000+fat2001+fat2002+fat2003+fat2004
scalar sum_d=r(estimate)
scalar se_d=r(se)

lincom femalet2004-femalet1979
scalar sum_e=r(estimate)
scalar se_e=r(se)
lincom fat1979+fat1980+fat1981+fat1982+fat1983+fat1984+fat1986+fat1987+fat1988+fat1989+fat1990+fat1991+fat1992+fat1993+fat1994+fat1996+fat1997+fat1998+fat1999+fat2000+fat2001+fat2002+fat2003
scalar sum_f=r(estimate)
scalar se_f=r(se)
lincom fat1979+fat1980+fat1981+fat1982+fat1983+2*fat1984+fat1986+fat1987+fat1988+fat1989+fat1990+fat1991+fat1992+fat1993+2*fat1994+fat1996+fat1997+fat1998+fat1999+fat2000+fat2001+fat2002+fat2003
scalar sum_g=r(estimate)
scalar se_g=r(se)

lincom femalet2002-femalet1979
scalar sum_h=r(estimate)
scalar se_h=r(se)
lincom femalet2001+fat2001-femalet1979
scalar sum_i=r(estimate)
scalar se_i=r(se)
lincom fat1979+fat1980+fat1981+fat1982+fat1983+fat1984+fat1986+fat1987+fat1988+fat1989+fat1990+fat1991+fat1992+fat1993+fat1994+fat1996+fat1997+fat1998+fat1999+fat2000+fat2001
scalar sum_j=r(estimate)
scalar se_j=r(se)
lincom fat1979+fat1980+fat1981+fat1982+fat1983+2*fat1984+fat1986+fat1987+fat1988+fat1989+fat1990+fat1991+fat1992+fat1993+2*fat1994+fat1996+fat1997+fat1998+fat1999+fat2000+fat2001
scalar sum_k=r(estimate)
scalar se_k=r(se)

estimates restore `participation'
estadd scalar sum_a=sum_a
estadd scalar se_a=se_a
estadd scalar sum_b=sum_b
estadd scalar se_b=se_b
estadd scalar sum_c=sum_c
estadd scalar se_c=se_c
estadd scalar sum_d=sum_d
estadd scalar se_d=se_d
estadd scalar sum_e=sum_e
estadd scalar se_e=se_e
estadd scalar sum_f=sum_f
estadd scalar se_f=se_f
estadd scalar sum_g=sum_g
estadd scalar se_g=se_g
estadd scalar sum_h=sum_h
estadd scalar se_h=se_h
estadd scalar sum_i=sum_i
estadd scalar se_i=se_i
estadd scalar sum_j=sum_j
estadd scalar se_j=se_j
estadd scalar sum_k=sum_k
estadd scalar se_k=se_k

estimates store `participation'
}

capture erase "${replication}tableA3.tex"
estout employed ft ///
	using "${replication}tableA3.tex", cells("b(star fmt(3)) se(fmt(3) par)") keep(fat* femalet1979 femalet2002 femalet2004) order(fat* femalet1979 femalet2002 femalet2004) ///
       stats(sum_a se_a sum_b se_b sum_c se_c sum_d se_d sum_e se_e sum_f se_f sum_g se_g sum_h se_h sum_i se_i sum_j se_j sum_k se_k, ///
       fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3) ///
       labels("gap05" "se" "delta7905" "se" "sum7904" "se" "sum7904fill" "se" "delta7904" "se" "sum7903" "se" "sum7903fill" "se" ///
              "delta7902" "se" "delta7902 in 01 panel" "se" "sum7901" "se" "sum7901fill" "se" )) ///
	numbers starlevels(* 0.10 ** 0.05 *** 0.01) append style(tex) 

end // program tableA3


*******************
/*TABLE A4*/
*******************

capture program drop tableA4
program define tableA4

clear
insheet using ${replication}cps.csv	

local particip employed ft 
local iv anychild6

local condition1 "if year>=1976 & year<=1980 & (eduhsless==1)"
local condition2 "if year>=1976 & year<=1980 & (edu12==1)"
local condition3 "if year>=1976 & year<=1980 & (edu1315==1)"
local condition4 "if year>=1976 & year<=1980 & (educollegeplus==1)"
local condition5 "if year>=1976 & year<=1980"
local condition6 "if year>=2001 & year<=2005 & (eduhsless==1)"
local condition7 "if year>=2001 & year<=2005 & (edu12==1)"
local condition8 "if year>=2001 & year<=2005 & (edu1315==1)"
local condition9 "if year>=2001 & year<=2005 & (educollegeplus==1)"
local condition10 "if year>=2001 & year<=2005"

foreach i in 1 {
forvalues j=1/10 {
if "`j'"=="5"|"`j'"=="10" local control "edu12 edu1315 educollegeplus"
if "`j'"!="5"&"`j'"!="10" local control ""
foreach participation in `particip' {
reg `participation' `iv' `control' [pw=wgt] `condition`j'' & female==`i'
estimates store `participation'_`i'_`j'
estadd ysumm, mean
}
}
}

capture erase "${replication}tableA4.tex"
forvalues j=1/5 {
local h=`j'
local i=`j'+5
estout employed_1_`h' employed_1_`i' ft_1_`h' ft_1_`i' ///
	using "${replication}tableA4.tex", cells(b(star fmt(3))) /*drop(_cons edu12 edu1315 educollegeplus)*/ stats(N ymean, fmt(0 3) labels("Obs" "Mean Y")) ///
	numbers starlevels(* 0.10 ** 0.05 *** 0.01) append style(tex) 
}

end // program tableA4


	

*******************
/*TABLE A5*/
/*FIGURE A2*/
/*FIGURE A3*/
*******************

capture program drop tableA5
program define tableA5 

clear
insheet using ${replication}cps.csv	

drop if year<=1978

*sum edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2
foreach var in edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2 {
replace `var'=0 if married==0
}
replace lnw_spouse2=0 if edusmissing==1
*sum edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2

local iv anychild6

local condition1 "if year>=1976 & year<=1980"
local condition2 "if year>=1981 & year<=1985"
local condition3 "if year>=1986 & year<=1990"
local condition4 "if year>=1991 & year<=1995"
local condition5 "if year>=1996 & year<=2000"
local condition6 "if year>=2001 & year<=2005"

gen rank=.
forvalues i=1/6 {
forvalues g=0/1 {
reg w_ft dage* divorced separated nevermarr edu0911 edu12 edu1315 edu16 edu17p edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2 [pw=wgt] `condition`i'' & female==`g' & ft==1
predict w`g'_`i' `condition`i'' & female==`g', xb
_pctile w`g'_`i' `condition`i'' & female==`g', p(25 50 75)
scalar p25=r(r1)
scalar p50=r(r2)
scalar p75=r(r3)
replace rank=1 `condition`i'' & female==`g' & w`g'_`i'<=p25
replace rank=2 `condition`i'' & female==`g' & w`g'_`i'<=p50 & w`g'_`i'>p25
replace rank=3 `condition`i'' & female==`g' & w`g'_`i'<=p75 & w`g'_`i'>p50
replace rank=4 `condition`i'' & female==`g' & w`g'_`i'>p75
}
}

*forvalues i=1/6 {
*bys female: tab rank `condition`i''
*}
*bys female: sum rank* w_* dage* divorced separated nevermarr edu0911 edu12 edu1315 edu16 edu17p edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2


forvalues j=1/6 {
foreach participation in ft {
forvalues i=1/4 {
reg w_`participation' female fiv [pw=wgt] `condition`j'' & `participation'==1 & rank==`i'
lincom female+fiv
matrix g`i'_`j'=(r(estimate)\r(se))'
reg w_`participation' female [pw=wgt] `condition`j'' & `participation'==1 & rank==`i'
matrix b=e(b)
matrix h`i'_`j'=(b[1,1]\0)'
reg `participation' `iv' [pw=wgt] `condition`j'' & female==1  & rank==`i'
}
}
}

matrix G=(g1_1,g2_1,g3_1,g4_1\g1_2,g2_2,g3_2,g4_2\g1_3,g2_3,g3_3,g4_3\g1_4,g2_4,g3_4,g4_4\g1_5,g2_5,g3_5,g4_5\g1_6,g2_6,g3_6,g4_6)
matrix H=(h1_1,h2_1,h3_1,h4_1\h1_2,h2_2,h3_2,h4_2\h1_3,h2_3,h3_3,h4_3\h1_4,h2_4,h3_4,h4_4\h1_5,h2_5,h3_5,h4_5\h1_6,h2_6,h3_6,h4_6)
matrix K=(g1_1',g2_1',g3_1',g4_1'\g1_2',g2_2',g3_2',g4_2'\g1_3',g2_3',g3_3',g4_3'\g1_4',g2_4',g3_4',g4_4'\g1_5',g2_5',g3_5',g4_5'\g1_6',g2_6',g3_6',g4_6')

preserve
svmat G
keep G*
drop if G1==.
gen x=_n
label define lyear 1 "1976-1980" 2 "1981-1985" 3  "1986-1990" 4 "1991-1995" 5 "1996-2000" 6 "2001-2005" 
label values x lyear

set obs 7
replace x=6.1 if _n==7

graph twoway (connected  G1 x, lpattern("dot") msymbol(smtriangle)) ///
	      (connected  G3 x, lpattern("shordash") msymbol(smsquare)) ///
	      (connected  G5 x, lpattern("solid") msymbol(smcircle)) ///
             (connected  G7 x, lpattern("longdash_dot") msymbol(smx)) , ///
             legend(rows(1) ring(3) region(color(none) margin(zero)) ///
                        /*size(small)*/ symysize(*.5) symxsize(*1.2)) ///
             legend(label(1 "< pct 25") label(2 "pct 25-50") label(3 "pct 50-75") label(4 "> pct 75")) ///
             graphregion(color(white) icolor(white)) ///
             ytitle("") xtitle("") xlabel(1(1)6, valuelabel labsize(small)) ylabel(-.5(.1)-.2, labsize(small)) 
graph save ${replication}figureA2.gph, asis replace
graph export ${replication}figureA2.eps, replace
restore

preserve
svmat H
keep H*
drop if H1==.
gen x=_n
label define lyear 1 "1976-1980" 2 "1981-1985" 3  "1986-1990" 4 "1991-1995" 5 "1996-2000" 6 "2001-2005" 
label values x lyear

set obs 7
replace x=6.1 if _n==7

graph twoway (connected  H1 x, lpattern("dot") msymbol(smtriangle)) ///
	      (connected  H3 x, lpattern("shordash") msymbol(smsquare)) ///
	      (connected  H5 x, lpattern("solid") msymbol(smcircle)) ///
             (connected  H7 x, lpattern("longdash_dot") msymbol(smx)) , ///
             legend(rows(1) ring(3) region(color(none) margin(zero)) ///
                        /*size(small)*/ symysize(*.5) symxsize(*1.2)) ///
             legend(label(1 "< pct 25") label(2 "pct 25-50") label(3 "pct 50-75") label(4 "> pct 75")) ///
             graphregion(color(white) icolor(white)) ///
             ytitle("") xtitle("") xlabel(1(1)6, valuelabel labsize(small)) ylabel(-.5(.1)-.2, labsize(small)) 
graph save ${replication}figureA3.gph, asis replace
graph export ${replication}figureA3.eps, replace
restore


local condition1 "if female==1 & year>=1976 & year<=1980"
local condition2 "if female==1 & year>=2001 & year<=2005"
local condition3 "if female==0 & year>=1976 & year<=1980"
local condition4 "if female==0 & year>=2001 & year<=2005"

local vars age eduhsless edu12 edu1315 educollegeplus married nevermarr child6_0 ft w_ft ftz0 ftz1 edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2


foreach var in edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2 {
replace `var'=. if married==0
}
replace lnw_spouse2=. if edusmissing==1
sum edushsless edus12 edus1315 eduscollegeplus edusmissing lnw_spouse2

forvalues i=1/4 {
forvalues j=1/4 {
tabstat `vars' [aw=wgt] `condition`i'' & rank==`j' , stats(mean) save
matrix A`j'=r(StatTotal)'
count `condition`i'' & rank==`j'
scalar num=r(N)
count `condition`i'' 
scalar den=r(N)
scalar pct=num/den
matrix A`j'= A`j' \ pct \ num
}
matrix B`i'= A1, A2, A3, A4
}
matrix B=[B1,B2\B3,B4]


matrix rownames B = "age" "less than hs" "hs grad" "some college" "college or more" "married" "never married" "no child leq 6" "full time" "wage ft" "ft no child6"  "ft child6 present" ///
"sp less than hs" "sp hs grad" "sp some college" "sp college or more" "sp missing" "sp lnwage" "pct" "N" ///
"age" "less than hs" "hs grad" "some college" "college or more" "married" "never married" "no child leq 6" "full time" "wage ft" "ft no child6"  "ft child6 present" ///
"sp less than hs" "sp hs grad" "sp some college" "sp college or more" "sp missing" "sp lnwage" "pct" "N"
matrix colnames B = "pct25" "pct25-50" "pct50-75" "pct75" "pct25" "pct25-50" "pct50-75" "pct75"
estout matrix(B, fmt(3)) using "${replication}tableA5.tex" , style(tex) title("Summary Statistics by Predicted Wage Quartile") replace


end // program tableA5


*********************************
/*FIGURE A4*/
*********************************

capture program drop figureA4
program define figureA4

clear
insheet using ${replication}cps.csv	

local iv anychild6
local condition1 "if year>=1976 & year<=1980"
local condition2 "if year>=1981 & year<=1985"
local condition3 "if year>=1986 & year<=1990"
local condition4 "if year>=1991 & year<=1995"
local condition5 "if year>=1996 & year<=2000"
local condition6 "if year>=2001 & year<=2005"

foreach edu in eduhsless edu12 edu1315 educollegeplus {
gen df_`edu'=female*`edu'
gen dfdz_`edu'=fiv*`edu'
gen dmdz_`edu'=miv*`edu'
}
local ge1 "(df_eduhsless+dfdz_eduhsless)"
local ge2 "(df_edu12+dfdz_edu12)"
local ge3 "(df_edu1315+dfdz_edu1315)"
local ge4 "(df_educollegeplus+dfdz_educollegeplus)"
local gme1 "(df_eduhsless)"
local gme2 "(df_edu12)"
local gme3 "(df_edu1315)"
local gme4 "(df_educollegeplus)"

*MALE FIRST STEP
forvalues i=1/6 {
tabstat eduhsless edu12 edu1315 educollegeplus [aw=wgt]  `condition`i'' & female==1 , stats(mean) save
matrix A`i'=r(StatTotal)'
foreach educ in eduhsless edu12 edu1315 educollegeplus {
dprobit ft `iv' [pw=wgt] `condition`i'' & female==0  & `educ'==1
estimates store ft`educ'_`i'
estadd ysumm, mean
}
dprobit ft `iv' eduhsless edu12 edu1315 educollegeplus [pw=wgt] `condition`i'' & female==0  
estimates store ft_`i'
estadd ysumm, mean
}
capture erase "${replication}figureA2_regs.tex"
forvalues h=1/6 {
estout fteduhsless_`h' ftedu12_`h' ftedu1315_`h' fteducollegeplus_`h' ft_`h' ///
	using "${replication}figureA2_rgs.tex", cells(dfdx(star fmt(3))) drop(_cons) stats(N ymean, fmt(0 3) labels("Obs" "Mean Y")) ///
	numbers starlevels(* 0.10 ** 0.05 *** 0.01) append style(tex) 
}


matrix B= A1, A2, A3, A4, A5, A6
matrix list B

forvalues i=1/6 {
foreach participation in ft {

scalar sca1 = B[1,`i']
scalar sca2 = B[2,`i']
scalar sca3 = B[3,`i']
scalar sca4 = B[4,`i']

reg w_`participation' eduhsless edu12 edu1315 educollegeplus df_e* dfdz_e* dmdz_e* [pw=wgt] `condition`i'' & `participation'==1, noc
estimates store `participation'_`i'
lincom sca1*`ge1'+sca2*`ge2'+sca3*`ge3'+sca4*`ge4'
matrix L`i'=(r(estimate)\r(se))'
reg w_`participation' eduhsless edu12 edu1315 educollegeplus df_e* dfdz_e* [pw=wgt] `condition`i'' & `participation'==1, noc
lincom sca1*`ge1'+sca2*`ge2'+sca3*`ge3'+sca4*`ge4'
matrix LL`i'=(r(estimate)\r(se))'
}
}


estout ft_1 ft_2 ft_3 ft_4 ft_5 ft_6 ///
	using "${replication}figureA2_rgs.tex", cells(b(star fmt(3)) se(fmt(3) par))  stats(N, fmt(0 3) labels("Obs")) ///
	numbers starlevels(* 0.10 ** 0.05 *** 0.01) append style(tex) 


matrix G=(L1,LL1\L2,LL2\L3,LL3\L4,LL4\L5,LL5\L6,LL6)
matrix K=(L1',LL1'\L2',LL2'\L3',LL3'\L4',LL4'\L5',LL5'\L6',LL6')

preserve
svmat G
keep G*
drop if G1==.
foreach i in 1 3 {
local j=`i'+1
gen hi_G`i' = G`i' + 1.96*G`j'
gen lo_G`i' = G`i' - 1.96*G`j'
}

gen x=_n
label define lyear 1 "1976-1980" 2 "1981-1985" 3  "1986-1990" 4 "1991-1995" 5 "1996-2000" 6 "2001-2005" 
label values x lyear

set obs 7
replace x=6.1 if _n==7

graph twoway (connected  G1 x, lpattern("solid") msymbol(smtriangle)) ///
	      (connected  G3 x, lpattern("shortdash") msymbol(smcircle)), ///
             legend(rows(2) ring(3) hole(3) region(color(none) margin(zero)) ///
                        /*size(small)*/ symysize(*.5) symxsize(*1.2) ///
                        label(1 "Female and Male AE") label(2 "Female AE and Male Population ")) ///
             graphregion(color(white) icolor(white)) ///
             ytitle("") xtitle("") xlabel(1(1)6, valuelabel labsize(small)) ylabel(-.5(.1)-.2, labsize(small)) 
graph save ${replication}figureA4.gph, asis replace
graph export ${replication}figureA4.eps, replace
restore


end // program figureA4


**********************
/*TABLE A6*/
**********************

capture program drop tableA6
program define tableA6

clear
insheet using ${replication}june.csv	

forvalues j=1/6 {
replace anychild`j'=. if female==0
}
replace nochild6=. if female==0

local condition1 "if female==1"
local condition2 "if female==1 & (year==1979|year==1980|year==1981|year==1982)"
local condition3 "if female==1 & (year==1994|year==1995|year==1998|year==2000|year==2002)"
local condition4 "if female==0"
local condition5 "if female==0 & (year==1979|year==1980|year==1981|year==1982)"
local condition6 "if female==0 & (year==1994|year==1995|year==1998|year==2000|year==2002)"

local vars married abssep widdiv nevermarr eduhsless edu12 edu1315 educollegeplus anychild6 anychild5 anychild4 anychild3 anychild2 anychild1 ///
employed w_employed employedz0_6 employedz1_6 employedz0_5 employedz1_5 employedz0_4 employedz1_4 employedz0_3 employedz1_3 employedz0_2 employedz1_2 employedz0_1 employedz1_1 ///
ft w_ft ftz0_6 ftz1_6 ftz0_5 ftz1_5 ftz0_4 ftz1_4 ftz0_3 ftz1_3 ftz0_2 ftz1_2 ftz0_1 ftz1_1

forvalues i=1/6 {
tabstat `vars' [aw=ernwgt] `condition`i'' , stats(mean) save
matrix A`i'=r(StatTotal)'
count `condition`i''
matrix A`i'= A`i' \ r(N)
}
matrix B= A1, A2, A3, A4, A5, A6

matrix rownames B = "\% married" "\% absent or separated" "\% widowed or divorced" "\% never married" "\% less than hs" "\% hs grad" "\% some college" "\% college or more" ///
"\% any child \leq 6" "\% any child \leq 5" "\% any child \leq 4" "\% any child \leq 3" "\% any child \leq 2" "\% any child \leq 1" ///
"\% employed" "ln(hourly wage)" "\% employed w/o child \leq 6" "\% employed w/ child \leq 6" "\% employed w/o child \leq 5" "\% employed w/ child \leq 5" ///
"\% employed w/o child \leq 4" "\% employed w/ child \leq 4" "\% employed w/o child \leq 3" "\% employed w/ child \leq 3" ///
"\% employed w/o child \leq 2" "\% employed w/ child \leq 2" "\% employed w/o child \leq 1" "\% employed w/ child \leq 1" ///
"\% full time" "ln(hourly wage)" "\% ft w/o child \leq 6" "\% ft w/ child \leq 6" "\% ft w/o child \leq 5" "\% ft w/ child \leq 5" ///
"\% ft w/o child \leq 4" "\% ft w/ child \leq 4" "\% ft w/o child \leq 3" "\% ft w/ child \leq 3" /// 
"\% ft w/o child \leq 2" "\% ft w/ child \leq 2" "\% ft w/o child \leq 1" "\% ft w/ child \leq 1" "observations"  
matrix colnames B = "F79-02" "F79-82" "F94-02" "M79-02" "M79-82" "M94-02"

capture erase "${replication}tableA6.tex"
estout matrix(B, fmt(3)) using "${replication}tableA6.tex" , style(tex) replace

end // program tableA6


*********************************
/*FIGURE A5*/
*********************************

capture program drop figureA5
program define figureA5

clear
insheet using ${replication}june.csv

local particip ft 
local ivvars anychild6 anychild5 anychild4 anychild3 anychild2 anychild1

local condition1 "if year>=1979 & year<=1982"
local condition2 "if year>=1983 & year<=1987"
local condition3 "if year>=1988 & year<=1992"
local condition4 "if year>=1994 & year<=2002"

foreach edu in eduhsless edu12 edu1315 educollegeplus {
gen df_`edu'=female*`edu'
forvalues i=1/6 {
gen dfdz`i'_`edu'=female*anychild`i'*`edu'
}
}
forvalues i=1/6 {
local ge1z`i' "(df_eduhsless+dfdz`i'_eduhsless)"
local ge2z`i' "(df_edu12+dfdz`i'_edu12)"
local ge3z`i' "(df_edu1315+dfdz`i'_edu1315)"
local ge4z`i' "(df_educollegeplus+dfdz`i'_educollegeplus)"
}

forvalues i=1/4 {
tabstat eduhsless edu12 edu1315 educollegeplus [aw=ernwgt]  `condition`i'' & female==1 , stats(mean) save
matrix A`i'=r(StatTotal)'
}
matrix B= A1, A2, A3, A4
matrix list B

forvalues j=1/6 {
forvalues i=1/4 {
foreach participation in ft {
scalar sca1 = B[1,`i']
scalar sca2 = B[2,`i']
scalar sca3 = B[3,`i']
scalar sca4 = B[4,`i']
reg w_`participation' eduhsless edu12 edu1315 educollegeplus df_e* dfdz`j'_e* [pw=ernwgt] `condition`i'' & `participation'==1, noc
estimates store lc`i'_z`j'
lincom sca1*`ge1z`j''+sca2*`ge2z`j''+sca3*`ge3z`j''+sca4*`ge4z`j''
matrix L`i'`j'=(r(estimate)\r(se))'
}
}
}

matrix G=(L11,L12,L13,L14,L15,L16\L21,L22,L23,L24,L25,L26\L31,L32,L33,L34,L35,L36\L41,L42,L43,L44,L45,L46)
matrix K=(L11',L12',L13',L14',L15',L16'\L21',L22',L23',L24',L25',L26'\L31',L32',L33',L34',L35',L36'\L41',L42',L43',L44',L45',L46')

svmat G
keep G*
drop if G1==.

gen x=_n
label define lyear 1 "1979-1982" 2 "1983-1987" 3  "1988-1992" 4 "1994-2002" 
label values x lyear
set obs 5
replace x=4.1 if _n==5

graph twoway (connected  G1 x, lpattern(solid) msymbol(smtriangle)) ///
	      (connected  G3 x, lpattern(longdash_dot) msymbol(smcircle)) ///
             (connected  G5 x, lpattern(shortdash) msymbol(smx)) /// 
	      (connected  G7 x, lpattern(longdash_dot) msymbol(smtriangle)) ///
	      (connected  G9 x, lpattern(shortdash) msymbol(smcircle)) ///
             (connected  G11 x, lpattern(solid) msymbol(smx)), ///
             legend(rows(2) ring(3) region(color(none) margin(zero)) ///
                        /*size(small)*/ symysize(*.5) symxsize(*1.2)) ///
             legend(label(1 "<1") label(2 "<2") label(3 "<3") label(4 "<4") label(5 "<5") label(6 "<6")) ///
             graphregion(color(white) icolor(white)) ///
             ytitle("") xtitle("") xlabel(1(1)4, valuelabel labsize(small)) ylabel(-.4(.1)-.1, labsize(small)) 
graph save ${replication}figureA5.gph, asis replace
graph export ${replication}figureA5.eps, replace


end // program figureA5


************************************************
/*FIGURE A1: combine figureA1_1 and figureA1_2*/
************************************************

capture program drop figureA1
program define figureA1

clear
insheet using ${replication}cps.csv	

preserve
gen educateg=.
replace educateg=1 if eduhsless==1
replace educateg=2 if edu12==1
replace educateg=3 if edu1315==1
replace educateg=4 if educollegeplus==1
gen y=.
replace y=1980 if year>=1976 & year<=1980

replace y=1985 if year>=1981 & year<=1985
replace y=1990 if year>=1986 & year<=1990
replace y=1995 if year>=1991 & year<=1995
replace y=2000 if year>=1996 & year<=2000
replace y=2005 if year>=2001 & year<=2005
drop year
rename y year

gridgen fval eval yval aval, start(0 1 1980 25) finish(1 4 2005 40) jump(1 1 5 5)
qui count if fval!=.
local n=r(N)
gen cell=.
gen pe=.
gen ub_p50=.
gen lb_p50=.
gen median=.
gen wcell=.

local i 1
while `i'<=`n' {
	gen ifval=.
	gen ieval=.
	gen iyval=.
	gen iaval=.
	gen universe=.
	gen e=.
	gen y=.
			
	replace ifval=1 if female==fval[`i']
	replace ieval=1 if educateg==eval[`i']
	replace iyval=1 if year==yval[`i']
	replace iaval=1 if age>=aval[`i'] & age<=aval[`i']+4
	replace universe=ifval*ieval*iyval*iaval
	replace e=employed*universe
	replace y=w_employed*employed*universe
	qui sum universe [aw=wgt]
	local cell=r(N)
	local wcell=r(sum)
	qui sum e [aw=wgt]
	local e=r(mean)
	local p50_u=100*0.5/`e'
	local p50_l=100*(0.5-(1-`e'))/`e'
		foreach var in 50 {
		if `=`p`var'_u''<100 qui _pctile y [pw=wgt], p(`p`var'_u')
		if `p`var'_u'<100 local ub_p`var'=r(r1)
		if `p`var'_u'<100 replace ub_p`var'=`ub_p`var'' if _n==`i'
		if `p`var'_l'>0 qui _pctile y [pw=wgt], p(`p`var'_l')
		if `p`var'_l'>0 local lb_p`var'=r(r1)
		if `p`var'_l'>0 replace lb_p`var'=`lb_p`var'' if _n==`i'
		}
		
	qui _pctile y [pw=wgt], p(50)
	local median=r(r1)
	replace median=`median' if _n==`i'	
	
	replace wcell=`wcell' if _n==`i'
	replace cell=`cell' if _n==`i'
	replace pe=`e' if _n==`i'	
	 
	drop ifval ieval iyval iaval universe e y 
	
	local i=`i'+1
}

keep if _n<=`n'
keep fval eval yval aval cell wcell pe ub_* lb_* median 
tempfile bounds_noiv
save `bounds_noiv'
restore


preserve
gen educateg=.
replace educateg=1 if eduhsless==1
replace educateg=2 if edu12==1
replace educateg=3 if edu1315==1
replace educateg=4 if educollegeplus==1
gen y=.
replace y=1980 if year>=1976 & year<=1980
replace y=2000 if year>=2001 & year<=2005
drop year
rename y year

drop if female==0
drop female
rename anychild6 female

gridgen fval eval yval aval, start(0 1 1980 25) finish(1 4 2000 40) jump(1 1 20 5)
qui count if fval!=.
local n=r(N)
gen cell=.
gen pe=.
gen ub_p50=.
gen lb_p50=.
gen median=.
gen wcell=.

local i 1
while `i'<=`n' {
	gen ifval=.
	gen ieval=.
	gen iyval=.
	gen iaval=.
	gen universe=.
	gen e=.
	gen y=.
			
	replace ifval=1 if female==fval[`i']
	replace ieval=1 if educateg==eval[`i']
	replace iyval=1 if year==yval[`i']
	replace iaval=1 if age>=aval[`i'] & age<=aval[`i']+4
	replace universe=ifval*ieval*iyval*iaval
	replace e=employed*universe
	replace y=w_employed*employed*universe
	qui sum universe [aw=wgt]
	local cell=r(N)
	local wcell=r(sum)
	qui sum e [aw=wgt]
	local e=r(mean)
	local p50_u=100*0.5/`e'
	local p50_l=100*(0.5-(1-`e'))/`e'
		foreach var in 50 {
		if `=`p`var'_u''<100 qui _pctile y [pw=wgt], p(`p`var'_u')
		if `p`var'_u'<100 local ub_p`var'=r(r1)
		if `p`var'_u'<100 replace ub_p`var'=`ub_p`var'' if _n==`i'
		if `p`var'_l'>0 qui _pctile y [pw=wgt], p(`p`var'_l')
		if `p`var'_l'>0 local lb_p`var'=r(r1)
		if `p`var'_l'>0 replace lb_p`var'=`lb_p`var'' if _n==`i'
		}
		
	qui _pctile y [pw=wgt], p(50)
	local median=r(r1)
	replace median=`median' if _n==`i'	
	
	replace wcell=`wcell' if _n==`i'
	replace cell=`cell' if _n==`i'
	replace pe=`e' if _n==`i'	
	 
	drop ifval ieval iyval iaval universe e y 
	
	local i=`i'+1
}

keep if _n<=`n'
keep fval eval yval aval cell wcell pe ub_* lb_* median 
rename fval anychild6
save ${replication}bounds_iv, replace
egen group=group(eval yval aval)
reshape wide cell wcell pe ub_* lb_* median, i(group) j(anychild6)
gen lbz=max(lb_p500,lb_p501)
gen ubz=min(ub_p500,ub_p501)
gen lbzn=max(median0,median1)
gen ubzp=min(median0,median1)

tempfile bounds_iv
save `bounds_iv'

restore

*figureA1_1

use `bounds_noiv', clear

keep if yval==1980|yval==2005
replace yval=2000 if yval==2005

drop cell pe wcell
egen group=group(eval yval aval)
reshape wide ub_* lb_* median, i(group) j(fval)
gen lb=lb_p501-ub_p500
gen ub=ub_p501-lb_p500
gen lbp=lb_p501-median0
gen ubp=median1-lb_p500

/*np is negative for women and positive for men*/

gen lbn=median1-ub_p500
gen ubn=ub_p501-median0
gen lbnp=median1-median0
gen ubnp=ub_p501-lb_p500

drop group ub_* lb_* median*
egen group=group(eval aval)
reshape wide lb ub lbp ubp lbn ubn lbnp ubnp, i(group) j(yval)
gen lb=lb2000-ub1980
gen ub=ub2000-lb1980
gen lbp=lbp2000-ubp1980
gen ubp=ubp2000-lbp1980

gen lbn=lbn2000-ubn1980
gen ubn=ubn2000-lbn1980
gen lbnp=lbp2000-ubnp1980
gen ubnp=ubp2000-lbnp1980

keep lb ub lbp ubp lbn ubn lbnp ubnp eval aval
bys eval: egen min_ub=min(ub)
bys eval: egen max_lb=max(lb)
bys eval: egen min_ubp=min(ubp)
bys eval: egen max_lbp=max(lbp)
bys eval: egen min_ubn=min(ubn)
bys eval: egen max_lbn=max(lbn)
bys eval: egen min_ubnp=min(ubnp)
bys eval: egen max_lbnp=max(lbnp)

bys eval: keep if _n==1
drop aval
rename min_ub min_ub0
rename max_lb max_lb0
rename min_ubp min_ub1
rename max_lbp max_lb1
rename min_ubn min_ub2
rename max_lbn max_lb2
rename min_ubnp min_ub3
rename max_lbnp max_lb3

keep min_* max_* eval
reshape long min_ub max_lb, i(eval) j(type)
preserve
keep if type==0|type==1

gen eval2=.
replace eval2=0 if eval==1
replace eval2=3 if eval==2
replace eval2=6 if eval==3
replace eval2=9 if eval==4
drop eval
rename eval2 eval
gen y=type+1
gen axis=y+eval

foreach cat in min_ub max_lb {
format `cat' %4.2f
}

#delimit ;
twoway (rcap min_ub max_lb axis if y==1, lwidth(medthick) lcolor(edkblue) lpattern(solid)) 
	(rcap min_ub max_lb axis if y==2, lwidth(medthick) lcolor(maroon) lpattern("-.-"))
	(scatter min_ub max_lb axis, mlabel(min_ub max_lb) msy(none none) mlabangle(30 30) mlabs(2.5 2.5) mlabc(black black)),
	scheme(s1color)
	xtitle("") ytitle("")
	ylabel(-.8(0.2)1.2, format(%9.1fc) angle(0) grid labs(small)) yline(0)
	legend(row(1) ring(3) region(color(none) margin(zero)) /*size(small)*/ symysize(*.5) symxsize(*1.2) order(1 "None" 2 "Positive Selection"))
	xtick(1.5 4.5 7.5 10.5) xlabel(1.5 "hs less" 4.5 "hs grad" 7.5 "some college" 10.5 "college more", labs(small));
#delimit cr
graph export "${replication}figureA1_1.eps", as(eps) replace

restore


*figureA1_1

use `bounds_iv', clear

rename lbz lb_p50
rename ubz ub_p50
rename ubzp median 
keep eval yval aval lb_p50 ub_p50 median
gen fval=1
tempfile iv
save `iv'
use `bounds_noiv', clear

keep if yval==1980|yval==2005
replace yval=2000 if yval==2005

drop cell pe wcell
drop if fval==1
append using `iv'

egen group=group(eval yval aval)
reshape wide ub_* lb_* median, i(group) j(fval)
gen lb=lb_p501-ub_p500
gen ub=ub_p501-lb_p500
gen lbp=lb_p501-median0
gen ubp=median1-lb_p500

gen lbn=median1-ub_p500
gen ubn=ub_p501-median0
gen lbnp=median1-median0
gen ubnp=ub_p501-lb_p500

drop group ub_* lb_* median*
egen group=group(eval aval)
reshape wide lb ub lbp ubp lbn ubn lbnp ubnp, i(group) j(yval)
gen lb=lb2000-ub1980
gen ub=ub2000-lb1980
gen lbp=lbp2000-ubp1980
gen ubp=ubp2000-lbp1980

gen lbn=lbn2000-ubn1980
gen ubn=ubn2000-lbn1980
gen lbnp=lbp2000-ubnp1980
gen ubnp=ubp2000-lbnp1980

keep lb ub lbp ubp lbn ubn lbnp ubnp eval aval
bys eval: egen min_ub=min(ub)
bys eval: egen max_lb=max(lb)
bys eval: egen min_ubp=min(ubp)
bys eval: egen max_lbp=max(lbp)
bys eval: egen min_ubn=min(ubn)
bys eval: egen max_lbn=max(lbn)
bys eval: egen min_ubnp=min(ubnp)
bys eval: egen max_lbnp=max(lbnp)

bys eval: keep if _n==1
drop aval
rename min_ub min_ub0
rename max_lb max_lb0
rename min_ubp min_ub1
rename max_lbp max_lb1
rename min_ubn min_ub2
rename max_lbn max_lb2
rename min_ubnp min_ub3
rename max_lbnp max_lb3

keep min_* max_* eval
reshape long min_ub max_lb, i(eval) j(type)

preserve
keep if type==0|type==1

gen eval2=.
replace eval2=0 if eval==1
replace eval2=3 if eval==2
replace eval2=6 if eval==3
replace eval2=9 if eval==4
drop eval
rename eval2 eval
gen y=type+1
gen axis=y+eval

foreach cat in min_ub max_lb {
format `cat' %4.2f
}

#delimit ;
twoway (rcap min_ub max_lb axis if y==1, lwidth(medthick) lcolor(edkblue) lpattern(solid)) 
	(rcap min_ub max_lb axis if y==2, lwidth(medthick) lcolor(maroon) lpattern("-.-"))
	(scatter min_ub max_lb axis, mlabel(min_ub max_lb) msy(none none) mlabangle(30 30) mlabs(2.5 2.5) mlabc(black black)),
	scheme(s1color)
	xtitle("") ytitle("")
	ylabel(-.8(0.2)1.2, format(%9.1fc) angle(0) grid labs(small)) yline(0)
	legend(row(1) ring(3) region(color(none) margin(zero)) /*size(small)*/ symysize(*.5) symxsize(*1.2) order(1 "IV" 2 "IV and Positive Selection"))
	xtick(1.5 4.5 7.5) xlabel(1.5 "hs less" 4.5 "hs grad" 7.5 "some college" 10.5 "college more", labs(small));
#delimit cr
graph export "${replication}figureA1_2.eps", as(eps) replace

restore


end // program figureA1

***********************
/*Running the program*/
***********************

tableA1
tableA2
tableA3
tableA4
tableA5
tableA6
figureA1
figureA4
figureA5
